@@ -1,5 +1,7 @@
 import hashlib
 import logging
+import os
+import sys
 from collections import defaultdict, OrderedDict
 from datetime import date
 from typing import DefaultDict, Any
@@ -716,21 +718,42 @@ def overall_report(members=None, limit=0):
         size_bracket: 0 for size_bracket in size_bracket_names
     }
 
+    gold_member_ids = []
+    silver_member_ids = []
+    bronze_member_ids = []
+    unclassified_member_ids = []
+
     total_items_unpreserved = 0
     total_items_preserved = 0
     total_preservation_instances = 0
     total_items_sampled = 0
 
+    plus_token = os.environ.get("CROSSREF_PLUS_TOKEN", None)
+
+    from crossref.restful import Etiquette, Members
+
+    my_etiquette = Etiquette(
+        "Preservation Status",
+        "0.01",
+        "https://eve.gd",
+        "meve@crossref.org",
+    )
+
     for member in members:
         logging.info(f"Fetching preservation statistics for member {member}")
 
-        from crossref.restful import Etiquette, Members
+        if plus_token:
+            members = Members(
+                etiquette=my_etiquette,
+                crossref_plus_token=plus_token,
+            )
+            logging.info(f"Using plus lookup")
+        else:
+            members = Members(etiquette=my_etiquette)
+            logging.info(f"Using regular lookup")
 
-        my_etiquette = Etiquette(
-            "Preservation Status", "0.01", "https://eve.gd", "meve@crossref.org"
-        )
+        logging.info(f"API lookup for {member}: done")
 
-        members = Members(etiquette=my_etiquette)
         member_obj = members.member(member)
 
         if "primary-name" not in member_obj:
@@ -752,7 +775,13 @@ def overall_report(members=None, limit=0):
             annotation_name="member-profile.json",
         )
 
-        annual_fee = int(member_data["annual-fee"])
+        logging.info(f"S3 fetches for member {member}: done")
+
+        try:
+            annual_fee = int(member_data["annual-fee"])
+        except ValueError:
+            annual_fee = 0
+
         member_band = None
 
         logging.info(
@@ -820,21 +849,27 @@ def overall_report(members=None, limit=0):
             bronze_members[member_band] += 1
             bronze_members_by_country[country] += 1
             bronze_members_by_size[size] += 1
+            bronze_member_ids.append(f"{member_obj['primary-name']} ({member})")
         elif preservations["member-grade"] == "Silver":
             logging.info(f"{member_obj['primary-name']} is Silver")
             silver_members[member_band] += 1
             silver_members_by_country[country] += 1
             silver_members_by_size[size] += 1
+            silver_member_ids.append(f"{member_obj['primary-name']} ({member})")
         elif preservations["member-grade"] == "Gold":
             logging.info(f"{member_obj['primary-name']} is Gold")
             gold_members[member_band] += 1
             gold_members_by_country[country] += 1
             gold_members_by_size[size] += 1
+            gold_member_ids.append(f"{member_obj['primary-name']} ({member})")
         else:
             logging.info(f"{member_obj['primary-name']} is Unclassified")
             unclassified_members[member_band] += 1
             unclassified_members_by_country[country] += 1
             unclassified_members_by_size[size] += 1
+            unclassified_member_ids.append(
+                f"{member_obj['primary-name']} ({member})"
+            )
 
     gold_totals = sum(gold_members.values())
     silver_totals = sum(silver_members.values())
@@ -863,6 +898,10 @@ def overall_report(members=None, limit=0):
         "total-items-unpreserved": total_items_unpreserved,
         "total-preservation-instances": total_preservation_instances,
         "total-items-sampled": total_items_sampled,
+        "gold-member-ids": gold_member_ids,
+        "silver-member-ids": silver_member_ids,
+        "bronze-member-ids": bronze_member_ids,
+        "unclassified-member-ids": unclassified_member_ids,
     }
 
     key = f"{REPORT_PATH}/{REPORT_FILENAME}"
